import { csvParse, select } from 'd3';
import { scatterPlot } from './scatterPlot';
import { data } from '@curran/iris-dataset';

export const main = (container, { state, setState }) => {
  const width = window.innerWidth;
  const height = window.innerHeight;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  const { hoveredValue } = state;

  const setHoveredValue = (d) => {
    setState((state) => ({
      ...state,
      hoveredValue: d,
    }));
  };

  svg.call(scatterPlot, {
    data,
    width,
    height,
    xValue: (d) => d.sepal_length,
    yValue: (d) => d.petal_length,
    colorValue: (d) => d.species,
    xAxisLabel: 'Sepal Length',
    yAxisLabel: 'Petal Length',
    colorLegendLabel: 'Species',
    margin: {
      top: 10,
      right: 10,
      bottom: 50,
      left: 50,
    },
    colorLegendX: 850,
    colorLegendY: 320,
    setHoveredValue,
    hoveredValue,
  });
};
